@@ -6,22 +6,25 @@ import datetime
 import json
 import socket
 import os.path
-from processor.helper.config.config_utils import config_value, framework_currentdata, TESTS, NODB, parsebool
+from processor.helper.config.config_utils import config_value, framework_currentdata, TESTS, DBTESTS, DBVALUES, SNAPSHOT
 from processor.helper.json.json_utils import json_from_file, save_json_to_file
 from processor.logging.log_handler import getlogger, FWLOGFILENAME
 from processor.helper.file.file_utils import remove_file, exists_dir, mkdir_path
 
 exclude_list = ['token', 'clientSecret', 'vaulttoken']
-logger = getlogger()
 
-def get_nodb():
+def get_dbtests():
     currdata = get_currentdata()
-    if NODB in currdata:
-        nodb = currdata[NODB]
+    if DBTESTS in currdata:
+        dbtests = currdata[DBTESTS]
     else:
-        nodb = parsebool(config_value(TESTS, NODB))
-        put_in_currentdata(NODB, nodb)
-    return nodb
+        nodb = config_value(TESTS, DBTESTS)
+        if nodb and nodb.upper() in DBVALUES:
+            dbtests = DBVALUES.index(nodb.upper())
+        else:
+            dbtests = DBVALUES.index(SNAPSHOT)
+        put_in_currentdata(DBTESTS, dbtests)
+    return dbtests
 
 
 
@@ -49,7 +52,7 @@ def init_currentdata():
 
 def put_in_currentdata(key, value):
     """Adds a value in the current run data"""
-    if key and value:
+    if key:
         curr_data = get_currentdata()
         if key in curr_data:
             val = curr_data[key]
@@ -99,6 +102,7 @@ def save_currentdata(curr_data):
 
 def delete_currentdata():
     """Delete the rundata file when exiting of the script."""
+    logger = getlogger()
     logger.critical("END: Completed the run and cleaning up.")
     runctx = get_currentdata()
     runctx['end'] = int(time.time() * 1000)
